__

package
v0.0.0-...-317c748 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 4, 2022 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Card_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "card.Card",
	HandlerType: (*CardServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCharacterCard",
			Handler:    _Card_GetCharacterCard_Handler,
		},
		{
			MethodName: "GetEquipCard",
			Handler:    _Card_GetEquipCard_Handler,
		},
		{
			MethodName: "GetSkillCard",
			Handler:    _Card_GetSkillCard_Handler,
		},
		{
			MethodName: "GetCharacterCardList",
			Handler:    _Card_GetCharacterCardList_Handler,
		},
		{
			MethodName: "GetEquipCardList",
			Handler:    _Card_GetEquipCardList_Handler,
		},
		{
			MethodName: "GetSkillCardList",
			Handler:    _Card_GetSkillCardList_Handler,
		},
		{
			MethodName: "GetCardList",
			Handler:    _Card_GetCardList_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "protos/v1/card/card.proto",
}

Card_ServiceDesc is the grpc.ServiceDesc for Card service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_protos_v1_card_card_proto protoreflect.FileDescriptor

Functions

func RegisterCardServer

func RegisterCardServer(s grpc.ServiceRegistrar, srv CardServer)

Types

type CardClient

type CardClient interface {
	GetCharacterCard(ctx context.Context, in *CardId, opts ...grpc.CallOption) (*CharacterCard, error)
	GetEquipCard(ctx context.Context, in *CardId, opts ...grpc.CallOption) (*EquipCard, error)
	GetSkillCard(ctx context.Context, in *CardId, opts ...grpc.CallOption) (*SkillCard, error)
	GetCharacterCardList(ctx context.Context, in *GetList, opts ...grpc.CallOption) (*CharacterCardList, error)
	GetEquipCardList(ctx context.Context, in *GetList, opts ...grpc.CallOption) (*EquipCardList, error)
	GetSkillCardList(ctx context.Context, in *GetList, opts ...grpc.CallOption) (*SkillCardList, error)
	GetCardList(ctx context.Context, in *GetList, opts ...grpc.CallOption) (*CardList, error)
}

CardClient is the client API for Card service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewCardClient

func NewCardClient(cc grpc.ClientConnInterface) CardClient

type CardId

type CardId struct {
	CardId int32 `protobuf:"varint,1,opt,name=cardId,proto3" json:"cardId,omitempty"`
	// contains filtered or unexported fields
}

req, res

func (*CardId) Descriptor deprecated

func (*CardId) Descriptor() ([]byte, []int)

Deprecated: Use CardId.ProtoReflect.Descriptor instead.

func (*CardId) GetCardId

func (x *CardId) GetCardId() int32

func (*CardId) ProtoMessage

func (*CardId) ProtoMessage()

func (*CardId) ProtoReflect

func (x *CardId) ProtoReflect() protoreflect.Message

func (*CardId) Reset

func (x *CardId) Reset()

func (*CardId) String

func (x *CardId) String() string

type CardList

type CardList struct {
	CharacterCards []*CharacterCardList `protobuf:"bytes,1,rep,name=characterCards,proto3" json:"characterCards,omitempty"`
	EquipCards     []*EquipCardList     `protobuf:"bytes,2,rep,name=equipCards,proto3" json:"equipCards,omitempty"`
	SkillCards     []*SkillCardList     `protobuf:"bytes,3,rep,name=skillCards,proto3" json:"skillCards,omitempty"`
	// contains filtered or unexported fields
}

func (*CardList) Descriptor deprecated

func (*CardList) Descriptor() ([]byte, []int)

Deprecated: Use CardList.ProtoReflect.Descriptor instead.

func (*CardList) GetCharacterCards

func (x *CardList) GetCharacterCards() []*CharacterCardList

func (*CardList) GetEquipCards

func (x *CardList) GetEquipCards() []*EquipCardList

func (*CardList) GetSkillCards

func (x *CardList) GetSkillCards() []*SkillCardList

func (*CardList) ProtoMessage

func (*CardList) ProtoMessage()

func (*CardList) ProtoReflect

func (x *CardList) ProtoReflect() protoreflect.Message

func (*CardList) Reset

func (x *CardList) Reset()

func (*CardList) String

func (x *CardList) String() string

type CardServer

type CardServer interface {
	GetCharacterCard(context.Context, *CardId) (*CharacterCard, error)
	GetEquipCard(context.Context, *CardId) (*EquipCard, error)
	GetSkillCard(context.Context, *CardId) (*SkillCard, error)
	GetCharacterCardList(context.Context, *GetList) (*CharacterCardList, error)
	GetEquipCardList(context.Context, *GetList) (*EquipCardList, error)
	GetSkillCardList(context.Context, *GetList) (*SkillCardList, error)
	GetCardList(context.Context, *GetList) (*CardList, error)
	// contains filtered or unexported methods
}

CardServer is the server API for Card service. All implementations must embed UnimplementedCardServer for forward compatibility

type CharacterCard

type CharacterCard struct {
	CardId         int32           `protobuf:"varint,1,opt,name=cardId,proto3" json:"cardId,omitempty"`
	Name           string          `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Desc           string          `protobuf:"bytes,3,opt,name=desc,proto3" json:"desc,omitempty"`
	Sprite         string          `protobuf:"bytes,4,opt,name=sprite,proto3" json:"sprite,omitempty"`
	Atk            int32           `protobuf:"varint,5,opt,name=atk,proto3" json:"atk,omitempty"`
	Hp             int32           `protobuf:"varint,6,opt,name=hp,proto3" json:"hp,omitempty"`
	Sd             int32           `protobuf:"varint,7,opt,name=sd,proto3" json:"sd,omitempty"`
	CharacterSkill *CharacterSkill `protobuf:"bytes,8,opt,name=characterSkill,proto3" json:"characterSkill,omitempty"`
	// contains filtered or unexported fields
}

캐릭터 카드

func (*CharacterCard) Descriptor deprecated

func (*CharacterCard) Descriptor() ([]byte, []int)

Deprecated: Use CharacterCard.ProtoReflect.Descriptor instead.

func (*CharacterCard) GetAtk

func (x *CharacterCard) GetAtk() int32

func (*CharacterCard) GetCardId

func (x *CharacterCard) GetCardId() int32

func (*CharacterCard) GetCharacterSkill

func (x *CharacterCard) GetCharacterSkill() *CharacterSkill

func (*CharacterCard) GetDesc

func (x *CharacterCard) GetDesc() string

func (*CharacterCard) GetHp

func (x *CharacterCard) GetHp() int32

func (*CharacterCard) GetName

func (x *CharacterCard) GetName() string

func (*CharacterCard) GetSd

func (x *CharacterCard) GetSd() int32

func (*CharacterCard) GetSprite

func (x *CharacterCard) GetSprite() string

func (*CharacterCard) ProtoMessage

func (*CharacterCard) ProtoMessage()

func (*CharacterCard) ProtoReflect

func (x *CharacterCard) ProtoReflect() protoreflect.Message

func (*CharacterCard) Reset

func (x *CharacterCard) Reset()

func (*CharacterCard) String

func (x *CharacterCard) String() string

type CharacterCardList

type CharacterCardList struct {
	CharacterCards []*CharacterCard `protobuf:"bytes,1,rep,name=characterCards,proto3" json:"characterCards,omitempty"`
	// contains filtered or unexported fields
}

func (*CharacterCardList) Descriptor deprecated

func (*CharacterCardList) Descriptor() ([]byte, []int)

Deprecated: Use CharacterCardList.ProtoReflect.Descriptor instead.

func (*CharacterCardList) GetCharacterCards

func (x *CharacterCardList) GetCharacterCards() []*CharacterCard

func (*CharacterCardList) ProtoMessage

func (*CharacterCardList) ProtoMessage()

func (*CharacterCardList) ProtoReflect

func (x *CharacterCardList) ProtoReflect() protoreflect.Message

func (*CharacterCardList) Reset

func (x *CharacterCardList) Reset()

func (*CharacterCardList) String

func (x *CharacterCardList) String() string

type CharacterSkill

type CharacterSkill struct {
	Name     string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Desc     string `protobuf:"bytes,2,opt,name=desc,proto3" json:"desc,omitempty"`
	Cooldown int32  `protobuf:"varint,3,opt,name=cooldown,proto3" json:"cooldown,omitempty"`
	// contains filtered or unexported fields
}

func (*CharacterSkill) Descriptor deprecated

func (*CharacterSkill) Descriptor() ([]byte, []int)

Deprecated: Use CharacterSkill.ProtoReflect.Descriptor instead.

func (*CharacterSkill) GetCooldown

func (x *CharacterSkill) GetCooldown() int32

func (*CharacterSkill) GetDesc

func (x *CharacterSkill) GetDesc() string

func (*CharacterSkill) GetName

func (x *CharacterSkill) GetName() string

func (*CharacterSkill) ProtoMessage

func (*CharacterSkill) ProtoMessage()

func (*CharacterSkill) ProtoReflect

func (x *CharacterSkill) ProtoReflect() protoreflect.Message

func (*CharacterSkill) Reset

func (x *CharacterSkill) Reset()

func (*CharacterSkill) String

func (x *CharacterSkill) String() string

type EquipCard

type EquipCard struct {
	// contains filtered or unexported fields
}

장비 카드

func (*EquipCard) Descriptor deprecated

func (*EquipCard) Descriptor() ([]byte, []int)

Deprecated: Use EquipCard.ProtoReflect.Descriptor instead.

func (*EquipCard) ProtoMessage

func (*EquipCard) ProtoMessage()

func (*EquipCard) ProtoReflect

func (x *EquipCard) ProtoReflect() protoreflect.Message

func (*EquipCard) Reset

func (x *EquipCard) Reset()

func (*EquipCard) String

func (x *EquipCard) String() string

type EquipCardList

type EquipCardList struct {
	EquipCards []*EquipCard `protobuf:"bytes,1,rep,name=equipCards,proto3" json:"equipCards,omitempty"`
	// contains filtered or unexported fields
}

func (*EquipCardList) Descriptor deprecated

func (*EquipCardList) Descriptor() ([]byte, []int)

Deprecated: Use EquipCardList.ProtoReflect.Descriptor instead.

func (*EquipCardList) GetEquipCards

func (x *EquipCardList) GetEquipCards() []*EquipCard

func (*EquipCardList) ProtoMessage

func (*EquipCardList) ProtoMessage()

func (*EquipCardList) ProtoReflect

func (x *EquipCardList) ProtoReflect() protoreflect.Message

func (*EquipCardList) Reset

func (x *EquipCardList) Reset()

func (*EquipCardList) String

func (x *EquipCardList) String() string

type GetList

type GetList struct {
	// contains filtered or unexported fields
}

func (*GetList) Descriptor deprecated

func (*GetList) Descriptor() ([]byte, []int)

Deprecated: Use GetList.ProtoReflect.Descriptor instead.

func (*GetList) ProtoMessage

func (*GetList) ProtoMessage()

func (*GetList) ProtoReflect

func (x *GetList) ProtoReflect() protoreflect.Message

func (*GetList) Reset

func (x *GetList) Reset()

func (*GetList) String

func (x *GetList) String() string

type SkillCard

type SkillCard struct {
	// contains filtered or unexported fields
}

스킬 카드

func (*SkillCard) Descriptor deprecated

func (*SkillCard) Descriptor() ([]byte, []int)

Deprecated: Use SkillCard.ProtoReflect.Descriptor instead.

func (*SkillCard) ProtoMessage

func (*SkillCard) ProtoMessage()

func (*SkillCard) ProtoReflect

func (x *SkillCard) ProtoReflect() protoreflect.Message

func (*SkillCard) Reset

func (x *SkillCard) Reset()

func (*SkillCard) String

func (x *SkillCard) String() string

type SkillCardList

type SkillCardList struct {
	SkillCards []*SkillCard `protobuf:"bytes,1,rep,name=skillCards,proto3" json:"skillCards,omitempty"`
	// contains filtered or unexported fields
}

func (*SkillCardList) Descriptor deprecated

func (*SkillCardList) Descriptor() ([]byte, []int)

Deprecated: Use SkillCardList.ProtoReflect.Descriptor instead.

func (*SkillCardList) GetSkillCards

func (x *SkillCardList) GetSkillCards() []*SkillCard

func (*SkillCardList) ProtoMessage

func (*SkillCardList) ProtoMessage()

func (*SkillCardList) ProtoReflect

func (x *SkillCardList) ProtoReflect() protoreflect.Message

func (*SkillCardList) Reset

func (x *SkillCardList) Reset()

func (*SkillCardList) String

func (x *SkillCardList) String() string

type UnimplementedCardServer

type UnimplementedCardServer struct {
}

UnimplementedCardServer must be embedded to have forward compatible implementations.

func (UnimplementedCardServer) GetCardList

func (UnimplementedCardServer) GetCharacterCard

func (UnimplementedCardServer) GetCharacterCardList

func (UnimplementedCardServer) GetEquipCard

func (UnimplementedCardServer) GetEquipCardList

func (UnimplementedCardServer) GetSkillCard

func (UnimplementedCardServer) GetSkillCardList

type UnsafeCardServer

type UnsafeCardServer interface {
	// contains filtered or unexported methods
}

UnsafeCardServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CardServer will result in compilation errors.

Jump to